@@ -3,8 +3,7 @@
 
 __author__ = 'Denis Cornehl'
 __email__ = 'denis.cornehl@gmail.com'
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 
-from closeio import CloseIO
-from closeio import CloseIOError
+from closeio import CloseIO, CloseIOError  # noqa
